<?xml version="1.0" encoding="UTF-8" ?>
<!--
	partyxml2html.xsl
	Created by Elmore, Jay on 2008-06-13.
	Copyright (c) 2008 Jay Elmore. All rights reserved.
-->

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:output encoding="UTF-8" indent="yes" method="html" />

	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:text>Party Roster</xsl:text>
				</title>
				<xsl:call-template name="style.declarations"/>
			</head>
			<body>
				<h1>Party Roster</h1>
				<xsl:for-each select="/partyxml/character">
					<xsl:apply-templates select="document(@filename)/pcint"/>
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="pcint">
		<table border="1" width="1200">
			<col span="12" width="75"/>
			<xsl:call-template name="table.header"/>
			<tr>
				<td colspan="2">
					<xsl:call-template name="pc.class.string"/>
				</td>
				<td>
					<xsl:value-of select="character_bio/alignment"/>
				</td>
				<td>
					<xsl:value-of select="senses/passive_insight"/>
				</td>
				<td>
					<xsl:value-of select="senses/passive_perception"/>
				</td>
				<td>
					<xsl:if test="combat/initiative &gt; -1">
						<xsl:text>+</xsl:text>
					</xsl:if>
					<xsl:value-of select="combat/initiative"/>
				</td>
				<td>
					<xsl:value-of select="combat/defenses/armor_class"/>
				</td>
				<td>
					<xsl:value-of select="combat/defenses/fortitude_defense"/>
				</td>
				<td>
					<xsl:value-of select="combat/defenses/reflex_defense"/>
				</td>
				<td>
					<xsl:value-of select="combat/defenses/will_defense"/>
				</td>
				<td>
					<xsl:value-of select="combat/hit_points"/>
				</td>
				<td>
					<xsl:value-of select="combat/bloodied"/>
				</td>
			</tr>
			<tr>
				<td colspan="6">
					<span class="faded">
						<xsl:text>Current HP</xsl:text>
					</span>
				</td>
				<td colspan="6">
					<span class="faded">
						<xsl:text>Healing Surges used</xsl:text>
					</span>
				</td>
			</tr>
			<tr>
				<td colspan="4">
					<xsl:apply-templates select="powers/power">
					</xsl:apply-templates>
				</td>
				<td colspan="4">
					<xsl:apply-templates select="powers/power">
					</xsl:apply-templates>
				</td>
				<td colspan="4">
					<xsl:apply-templates select="powers/power">
					</xsl:apply-templates>
				</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template match="powers/power">
	</xsl:template>

	<!-- ################################ -->
	<!-- Static formatted block templates -->
	<!-- ################################ -->
	<xsl:template name="table.header">
		<tr>
			<th colspan="1">
				<em>
					<xsl:value-of select="character_bio/playername"/>
				</em>
			</th>
			<th colspan="2">
				<xsl:value-of select="character_bio/name"/>
			</th>
			<th>P Ins.</th>
			<th>P Per.</th>
			<th>Init</th>
			<th>AC</th>
			<th>Fort</th>
			<th>Ref</th>
			<th>Will</th>
			<th>HP</th>
			<th>Blood</th>
		</tr>
	</xsl:template>

	<xsl:template name="style.declarations">
		<style type="text/css">
			<xsl:text>&#xA;</xsl:text>
			<xsl:text>body {font-family: "Mentor Sans Std", Optima, sans-serif; font-style: normal;}</xsl:text>
			<xsl:text>&#xA;</xsl:text>
			<xsl:text>em {font-family: "Mentor Std", Optima, sans-serif;font-style: italic;}</xsl:text>
			<xsl:text>&#xA;</xsl:text>
			<xsl:text>span.faded {color: #AAAAAA;}</xsl:text>
			<xsl:text>&#xA;</xsl:text>
		</style>
	</xsl:template>


	<xsl:template name="pc.class.string">
		<xsl:value-of select="character_bio/race"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="character_bio/class"/>
		<xsl:if test="character_bio/class='Cleric' or character_bio/class='Paladin'">
			<xsl:if test="count(character_bio/deity) and character_bio/deity != ''">
				<xsl:text> of </xsl:text>
				<xsl:value-of select="character_bio/deity"/>
			</xsl:if>
		</xsl:if>
		<xsl:if test="count(character_bio/paragon_path) and character_bio/paragon_path != ''">
			<xsl:text> / </xsl:text>
			<xsl:value-of select="character_bio/paragon_path"/>
		</xsl:if>
		<xsl:if test="count(character_bio/epic_destiny) and character_bio/epic_destiny != ''">
			<xsl:text> / </xsl:text>
			<xsl:value-of select="character_bio/epic_destiny"/>
		</xsl:if>
		<xsl:text> </xsl:text>
		<xsl:value-of select="character_bio/level"/>
	</xsl:template>

</xsl:stylesheet>
