<?xml version="1.0" encoding="UTF-8"?>
<!--
	pcint2html.xsl
	Created by Jay Elmore on 2008-05-12
	Copyright (c) 2008 Jay Elmore. All rights reserved.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output encoding="UTF-8" indent="yes" method="html"/>

	<!-- Variables for formatting purposes -->
	<xsl:param name="ext_first_power"/>
	<xsl:param name="ext_last_power"/>
	<xsl:param name="int_first_power"/>
	<xsl:param name="int_last_power"/>
	<xsl:variable name="powers-count" select="count(pcint/powers/power)"/>

	<xsl:template match="/">
		<!--<xsl:apply-templates select="pcint" mode="powers"/>-->
		<!-- Uncomment the upper line and comment out the lower line to get powers only -->
		<xsl:apply-templates select="pcint" mode="powers"/>

	</xsl:template>

	<!-- ########## -->
	<!-- Main block -->
	<!-- ########## -->
	<xsl:template match="pcint">
		<html>
			<head>
				<title>
					<xsl:value-of select="character_bio/name"/>
					<xsl:text>, </xsl:text>
					<xsl:value-of select="character_bio/race"/>
					<xsl:text> </xsl:text>
					<xsl:value-of select="character_bio/class"/>
				</title>
				<xsl:call-template name="style.declarations"/>
			</head>
			<body>
				<table width="900" border="2">
					<col span="12" width="75"/>
					<tr>
						<td colspan="12">
							<table width="100%">
								<tr>
									<td>
										<strong>
											<xsl:value-of select="character_bio/name"/>
										</strong>
									</td>
									<td align="right">
										<em>
											<xsl:value-of select="character_bio/playername"/>
										</em>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="12">
							<table width="100%">
								<tr>
									<td>
										<strong>
											<xsl:value-of select="character_bio/race"/>
											<xsl:text> (</xsl:text>
											<xsl:value-of select="character_bio/alignment"/>
											<xsl:text>)</xsl:text>
										</strong>
									</td>
									<td align="right">
										<strong>
											<xsl:call-template name="pc.class.string.noname"/>
										</strong>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="2" valign="top">
							<strong>
								<xsl:text>Initiative</xsl:text>
							</strong>
						</td>
						<td align="right">
							<xsl:if test="combat/initiative &gt; -1">
								<xsl:text>+</xsl:text>
							</xsl:if>
							<xsl:value-of select="combat/initiative"/>
						</td>
						<td colspan="6" valign="top">
						</td>
						<td colspan="2" valign="top">
							<strong>
								<xsl:text>Speed</xsl:text>
							</strong>
						</td>
						<td align="right">
							<xsl:value-of select="combat/speed"/>
							<xsl:text> squares</xsl:text>
						</td>
					</tr>
					<tr>
						<td colspan="3" valign="top">
							<xsl:apply-templates select="stats"/>
						</td>
						<td colspan="3" valign="top">
							<xsl:apply-templates select="combat/defenses"/>
						</td>
						<td colspan="3" valign="top">
							<xsl:apply-templates select="combat"/>
						</td>
						<td colspan="3" valign="top">
							<xsl:apply-templates select="senses"/>
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="4" rowspan="2">
							<xsl:apply-templates select="skills"/>
						</td>
						<td valign="top" colspan="4">
							<xsl:apply-templates select="features"/>
						</td>
						<td colspan="4" rowspan="2">
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="4">
							<xsl:apply-templates select="feats"/>
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="12">
							<xsl:apply-templates select="combat/attacks"/>
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="6">
							<xsl:apply-templates select="powers">
								<xsl:with-param name="ext_first_power" select="1"/>
								<xsl:with-param name="ext_last_power" select="floor(number($powers-count div 2))"/>
							</xsl:apply-templates>
						</td>
						<td valign="top" colspan="6">
							<xsl:apply-templates select="powers">
								<xsl:with-param name="ext_first_power" select="floor(number($powers-count div 2)) + 1"/>
								<xsl:with-param name="ext_last_power" select="999"/>
							</xsl:apply-templates>
						</td>
					</tr>
					<!--
						<tr>
							<td></td>
							<td></td>
							<td></td>
							<td></td>
							<td></td>
							<td></td>
							<td></td>
							<td></td>
							<td></td>
							<td></td>
							<td></td>
							<td></td>
						</tr>
					-->
				</table>
			</body>
		</html>
	</xsl:template>

	<!-- ######################## -->
	<!-- Main block (powers only)-->
	<!-- ######################## -->
	<xsl:template match="pcint" mode="powers">
		<html>
			<head>
				<title>
					<xsl:value-of select="character_bio/name"/>
					<xsl:text>, </xsl:text>
					<xsl:value-of select="character_bio/race"/>
					<xsl:text> </xsl:text>
					<xsl:value-of select="character_bio/class"/>
				</title>
				<xsl:call-template name="style.declarations"/>
			</head>
			<body>
				<table width="900" border="1">
					<col span="12" width="75"/>
					<tr>
						<td colspan="12">
							<table width="100%">
								<tr>
									<td>
										<strong>
											<xsl:value-of select="character_bio/name"/>
										</strong>
									</td>
									<td align="right">
										<em>
											<xsl:value-of select="character_bio/playername"/>
										</em>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td colspan="12">
							<table width="100%">
								<tr>
									<td>
										<strong>
											<xsl:value-of select="character_bio/race"/>
											<xsl:text> (</xsl:text>
											<xsl:value-of select="character_bio/alignment"/>
											<xsl:text>)</xsl:text>
										</strong>
									</td>
									<td align="right">
										<strong>
											<xsl:call-template name="pc.class.string.noname"/>
										</strong>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="12">
							<xsl:apply-templates select="combat/attacks"/>
						</td>
					</tr>
					<tr>
						<td valign="top" colspan="6">
							<xsl:apply-templates select="powers">
								<xsl:with-param name="ext_first_power" select="1"/>
								<xsl:with-param name="ext_last_power" select="floor(number($powers-count div 2))"/>
							</xsl:apply-templates>
						</td>
						<td valign="top" colspan="6">
							<xsl:apply-templates select="powers">
								<xsl:with-param name="ext_first_power" select="floor(number($powers-count div 2)) + 1"/>
								<xsl:with-param name="ext_last_power" select="999"/>
							</xsl:apply-templates>
						</td>
					</tr>
				</table>
			</body>
		</html>
	</xsl:template>

	<!-- ########### -->
	<!-- Stats block -->
	<!-- ########### -->
	<xsl:template match="stats">
		<table border="1" width="100%">
			<tr>
				<th colspan="3">
					<xsl:text>Ability Scores</xsl:text>
				</th>
			</tr>
			<tr>
				<td align="right">
					<strong>
						<xsl:text>Str</xsl:text>
					</strong>
				</td>
				<td>
					<xsl:value-of select="./strength"/>
				</td>
				<td align="right">
					<xsl:if test="./str_mod &gt; -1">
						<xsl:text>+</xsl:text>
					</xsl:if>
					<xsl:value-of select="./str_mod"/>
				</td>
			</tr>
			<tr>
				<td align="right">
					<strong>
						<xsl:text>Con</xsl:text>
					</strong>
				</td>
				<td>
					<xsl:value-of select="./constitution"/>
				</td>
				<td align="right">
					<xsl:if test="./con_mod &gt; -1">
						<xsl:text>+</xsl:text>
					</xsl:if>
					<xsl:value-of select="./con_mod"/>
				</td>
			</tr>
			<tr>
				<td align="right">
					<strong>
						<xsl:text>Dex</xsl:text>
					</strong>
				</td>
				<td>
					<xsl:value-of select="./dexterity"/>
				</td>
				<td align="right">
					<xsl:if test="./dex_mod &gt; -1">
						<xsl:text>+</xsl:text>
					</xsl:if>
					<xsl:value-of select="./dex_mod"/>
				</td>
			</tr>
			<tr>
				<td align="right">
					<strong>
						<xsl:text>Int</xsl:text>
					</strong>
				</td>
				<td>
					<xsl:value-of select="./intelligence"/>
				</td>
				<td align="right">
					<xsl:if test="./int_mod &gt; -1">
						<xsl:text>+</xsl:text>
					</xsl:if>
					<xsl:value-of select="./int_mod"/>
				</td>
			</tr>
			<tr>
				<td align="right">
					<strong>
						<xsl:text>Wis</xsl:text>
					</strong>
				</td>
				<td>
					<xsl:value-of select="./wisdom"/>
				</td>
				<td align="right">
					<xsl:if test="./wis_mod &gt; -1">
						<xsl:text>+</xsl:text>
					</xsl:if>
					<xsl:value-of select="./wis_mod"/>
				</td>
			</tr>
			<tr>
				<td align="right">
					<strong>
						<xsl:text>Cha</xsl:text>
					</strong>
				</td>
				<td>
					<xsl:value-of select="./charisma"/>
				</td>
				<td align="right">
					<xsl:if test="./cha_mod &gt; -1">
						<xsl:text>+</xsl:text>
					</xsl:if>
					<xsl:value-of select="./cha_mod"/>
				</td>
			</tr>     
		</table>
	</xsl:template>

	<!-- ############ -->
	<!-- Combat Block -->
	<!-- ############ -->
	<!-- Hit points and healing surges -->
	<xsl:template match="combat">
		<table width="100%">
			<tr>
				<th colspan="2">
					<xsl:text></xsl:text>
				</th>
			</tr>
			<tr>
				<td>
					<xsl:text>Hit Points</xsl:text>
				</td>
				<td align="right">
					<xsl:value-of select="./hit_points"/>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:text>Bloodied</xsl:text>
				</td>
				<td align="right">
					<xsl:value-of select="./bloodied"/>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:text>Healing Surges/Day</xsl:text>
				</td>
				<td align="right">
					<xsl:value-of select="./healing_surges"/>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:text>HP Healed/Surge</xsl:text>
				</td>
				<td align="right">
					<xsl:value-of select="./surge_value"/>
				</td>
			</tr>
		</table>
	</xsl:template>
	<!-- Defenses block -->
	<xsl:template match="combat/defenses">
		<table width="100%">
			<tr>
				<th colspan="2">
					<xsl:text>Defenses</xsl:text>
				</th>
			</tr>
			<tr>
				<td>
					<xsl:text>Armor Class</xsl:text>
				</td>
				<td>
					<xsl:value-of select="./armor_class"/>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:text>Fortitude</xsl:text>
				</td>
				<td>
					<xsl:value-of select="./fortitude_defense"/>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:text>Reflex</xsl:text>
				</td>
				<td>
					<xsl:value-of select="./reflex_defense"/>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:text>Will</xsl:text>
				</td>
				<td>
					<xsl:value-of select="./will_defense"/>
				</td>
			</tr>
		</table>
	</xsl:template>
	<!-- Basic attacks block -->
	<xsl:template match="combat/attacks">
		<table>
			<tr>
				<th colspan="2">
					<xsl:text>Basic Attacks</xsl:text>
				</th>
			</tr>
			<xsl:apply-templates select="./melee"/>
			<xsl:apply-templates select="./ranged"/>
		</table>
	</xsl:template>
	<xsl:template match="melee">
		<xsl:if test="count(./name) and ./name != ''">
			<tr>
				<td>
					<xsl:text>(M) </xsl:text>
					<xsl:value-of select="./name"/>
				</td>
				<td>
					<xsl:value-of select="./attack_modifier"/>
					<xsl:text> vs. </xsl:text>
					<xsl:value-of select="./vs_defense"/>
				</td>
				<td>
					<xsl:value-of select="./damage"/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ranged">
		<xsl:if test="count(./name) and ./name != ''">
			<tr>
				<td>
					<xsl:text>(R) </xsl:text>
					<xsl:value-of select="./name"/>
				</td>
				<td>
					<xsl:value-of select="./attack_modifier"/>
					<xsl:text> vs. </xsl:text>
					<xsl:value-of select="./vs_defense"/>
				</td>
				<td>
					<xsl:value-of select="./damage"/>
				</td>
				<td>
					<xsl:value-of select="./range_normal"/>
					<xsl:text> squares normal/</xsl:text>
					<xsl:value-of select="./range_max"/>
					<xsl:text> squares max</xsl:text>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

	<!-- ############ -->
	<!-- Senses Block -->
	<!-- ############ -->
	<xsl:template match="senses">
		<table width="100%">
			<tr>
				<td>
					<strong>
						<xsl:text>Passive Insight</xsl:text>
					</strong>
				</td>
				<td align="right">
					<strong>
						<xsl:value-of select="./passive_insight"/>
					</strong>
				</td>
			</tr>
			<tr>
				<td>
					<strong>
						<xsl:text>Passive Perception</xsl:text>
					</strong>
				</td>
				<td align="right">
					<strong>
						<xsl:value-of select="./passive_perception"/>
					</strong>
				</td>
			</tr>
			<tr>
				<td>
					<strong>
						<xsl:text>Vision: </xsl:text>
					</strong>	
					<xsl:value-of select="./vision"/>
				</td>
			</tr>
		</table>
	</xsl:template>

	<!-- ############ -->
	<!-- Skills block -->
	<!-- ############ -->
	<xsl:template match="skills">
		<table width="100%">
			<tr>
				<th colspan="2">
					<xsl:text>Skills</xsl:text>
				</th>
			</tr>
			<xsl:apply-templates select="skill"/>
		</table>
	</xsl:template>
	<xsl:template match="skill">
		<tr>
			<td>
				<xsl:value-of select="./name"/>
				<xsl:if test="count(./trained)">
					<em>
						<xsl:text> (trained)</xsl:text>
					</em>
				</xsl:if>
			</td>
			<td align="right">
				<xsl:if test="./modifier &gt; -1">
					<xsl:text>+</xsl:text>
				</xsl:if>
				<xsl:value-of select="./modifier"/>
			</td>
		</tr>
	</xsl:template> 

	<!-- ########### -->
	<!-- Feats block -->
	<!-- ########### -->
	<xsl:template match="feats">
		<table>
			<tr>
				<th colspan="2">
					<xsl:text>Feats</xsl:text>
				</th>
			</tr>
			<xsl:apply-templates select="feat"/>
		</table>
	</xsl:template>
	<xsl:template match="feat">
		<tr>
			<td valign="top">
				<xsl:value-of select="./name"/>
			</td>
			<td valign="top">
				<em>
					<xsl:text>(</xsl:text>
					<xsl:value-of select="./description"/>
					<xsl:text>)</xsl:text>
				</em>
			</td>
		</tr>
	</xsl:template> 

	<!-- ############################# -->
	<!-- Class and race features block -->
	<!-- ############################# -->
	<xsl:template match="features">
		<table>
			<tr>
				<th colspan="2">
					<xsl:text>Class and Race Features</xsl:text>
				</th>
			</tr>
			<xsl:apply-templates select="feature">
				<xsl:sort select="name"/>
			</xsl:apply-templates>
		</table>
	</xsl:template>
	<xsl:template match="feature">
		<tr>
			<td valign="top">
				<xsl:value-of select="./name"/>
			</td>
			<td valign="top">
				<em>
					<xsl:text>(</xsl:text>
					<xsl:value-of select="./description"/>
					<xsl:text>)</xsl:text>
				</em>
			</td>
		</tr>
	</xsl:template> 

	<!-- ############################# -->
	<!-- Powers block -->
	<!-- ############################# -->
	<xsl:template match="powers">
		<xsl:param name="ext_first_power"/>
		<xsl:param name="ext_last_power"/>
		<xsl:apply-templates select="power">
			<xsl:with-param name="int_first_power" select="$ext_first_power"/>
			<xsl:with-param name="int_last_power" select="$ext_last_power"/>
			<xsl:sort select="./uses"/>
			<xsl:sort select="./name"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="power">
		<xsl:param name="int_first_power"/>
		<xsl:param name="int_last_power"/>
		<xsl:if test="position() &gt;= $int_first_power">
			<xsl:if test="position() &lt;= $int_last_power">
				<table width="100%" cellspacing="0" cellpadding="2">
					<tr>
						<xsl:choose>
							<xsl:when test="./uses='Encounter'">                  
								<th width="10">
									<xsl:text>&#x274F; </xsl:text>
								</th>
								<th align="left" style="background-color:rgb(104,17,38); color:white;"> <!-- Encounter -->
									<xsl:value-of select="./name"/>
								</th>
								<th align="right" style="background-color:rgb(104,17,38); color:white;"> <!-- Encounter -->
									<xsl:value-of select="./type"/>
								</th>
							</xsl:when>
							<xsl:when test="./uses='At-Will'">
								<th colspan="2" align="left" style="background-color:rgb(77,125,79); color:white;"> <!-- At-Will -->
									<xsl:value-of select="./name"/>
								</th>
								<th align="right" style="background-color:rgb(77,125,79); color:white;"> <!-- At-Will -->
									<xsl:value-of select="./type"/>
								</th>
							</xsl:when>
							<xsl:when test="./uses='Daily'">
								<th width="10">
									<xsl:text>&#x274F; </xsl:text>
								</th>
								<th align="left" style="background-color:rgb(50,50,50); color:white;"> <!-- Daily -->
									<xsl:value-of select="./name"/>
								</th>
								<th align="right" style="background-color:rgb(50,50,50); color:white;"> <!-- Daily -->
									<xsl:value-of select="./type"/>
								</th>
							</xsl:when>
						</xsl:choose>
					</tr>
					<xsl:if test="count(./description)">
						<tr>
							<td colspan="3">
								<em>
									<xsl:value-of select="./description"/>
								</em>
							</td>
						</tr>
					</xsl:if>
					<tr>
						<td colspan="3">
							<strong>
								<xsl:value-of select="./uses"/>
								<xsl:if test="count(./keyword)">
									<xsl:text> &#x2726; </xsl:text>
								</xsl:if>
								<xsl:apply-templates select="./keyword">
									<xsl:sort select="text()"/>
								</xsl:apply-templates>
							</strong>
						</td>
					</tr>
					<tr>
						<td colspan="2">
							<strong>
								<xsl:value-of select="./action_type"/>
								<xsl:if test="./action_type != 'Immediate Interrupt' and ./action_type != 'Immediate Reaction'">
									<xsl:text> action</xsl:text>
								</xsl:if>
							</strong>
						</td>
						<td>
							<strong>
								<xsl:value-of select="./range"/>
							</strong>
							<xsl:if test="count(./area)">
								<xsl:text> </xsl:text>
								<xsl:value-of select="./area"/>
							</xsl:if>
						</td>
					</tr>
					<xsl:if test="count(./prerequisite)">
						<tr>
							<td colspan="3">
								<strong>
									<xsl:text>Prerequisite: </xsl:text>
								</strong>
								<xsl:value-of select="./prerequisite"/>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="count(./requirement)">
						<tr>
							<td colspan="3">
								<strong>
									<xsl:text>Requirement: </xsl:text>
								</strong>
								<xsl:value-of select="./requirement"/>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="count(./special)">
						<tr>
							<td colspan="3">
								<strong>
									<xsl:text>Special: </xsl:text>
								</strong>
								<xsl:value-of select="./special"/>
							</td>
						</tr>
					</xsl:if>
					<xsl:apply-templates select="./primary"/>
					<xsl:apply-templates select="./secondary"/>
					<xsl:apply-templates select="./tertiary"/>
				</table>
			</xsl:if>
		</xsl:if>
	</xsl:template>

	<xsl:template match="keyword">
		<xsl:value-of select="text()"/>
		<xsl:if test="position() != last()">
			<xsl:text>, </xsl:text>
		</xsl:if>
	</xsl:template>

	<xsl:template match="primary | secondary | tertiary">
		<xsl:if test="count(./target)">
			<tr>
				<td colspan="3">
					<strong>
						<xsl:choose>
							<xsl:when test="name()='secondary'">
								<xsl:text>Secondary Target: </xsl:text>
							</xsl:when>
							<xsl:when test="name()='tertiary'">
								<xsl:text>Tertiary Target: </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>Target: </xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</strong>
					<xsl:value-of select="./target"/>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="count(./attack_modifier)">
			<tr>
				<td colspan="3">
					<strong>
						<xsl:choose>
							<xsl:when test="name()='secondary'">
								<xsl:text>Secondary Attack: </xsl:text>
							</xsl:when>
							<xsl:when test="name()='tertiary'">
								<xsl:text>Tertiary Attack: </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>Attack: </xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</strong>
					<xsl:value-of select="./attack_modifier"/>
					<xsl:text> vs. </xsl:text>
					<xsl:value-of select="./vs_defense"/>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="count(./hit)">
			<tr>
				<td colspan="3">
					<strong>
						<xsl:choose>
							<xsl:when test="name()='secondary'">
								<xsl:text>Secondary Hit: </xsl:text>
							</xsl:when>
							<xsl:when test="name()='tertiary'">
								<xsl:text>Tertiary Hit: </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>Hit: </xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</strong>
					<xsl:value-of select="./hit"/>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="count(./miss)">
			<tr>
				<td colspan="3">
					<strong>
						<xsl:choose>
							<xsl:when test="name()='secondary'">
								<xsl:text>Secondary Miss: </xsl:text>
							</xsl:when>
							<xsl:when test="name()='tertiary'">
								<xsl:text>Tertiary Miss: </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>Miss: </xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</strong>
					<xsl:value-of select="./miss"/>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="count(./effect)">
			<tr>
				<td colspan="3">
					<strong>
						<xsl:choose>
							<xsl:when test="name()='secondary'">
								<xsl:text>Secondary Effect: </xsl:text>
							</xsl:when>
							<xsl:when test="name()='tertiary'">
								<xsl:text>Tertiary Effect: </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>Effect: </xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</strong>
					<xsl:value-of select="./effect"/>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="count(./sustain)">
			<tr>
				<td colspan="3">
					<strong>
						<xsl:text>Sustain: </xsl:text>
					</strong>
					<xsl:value-of select="./sustain"/>
				</td>
			</tr>        
		</xsl:if>
	</xsl:template>

	<!-- ################################ -->
	<!-- Static formatted block templates -->
	<!-- ################################ -->
	<xsl:template name="style.declarations">
		<style type="text/css">
			<xsl:text>&#xA;</xsl:text>
			<xsl:text>body {font-family: "Mentor Sans Std", Optima, sans-serif; font-style: normal;}</xsl:text>
			<xsl:text>&#xA;</xsl:text>
			<xsl:text>em {font-family: "Mentor Std", Optima, sans-serif;font-style: italic;}</xsl:text>
			<xsl:text>&#xA;</xsl:text>
		</style>
	</xsl:template>

	<xsl:template name="pc.class.string.noname">
		<xsl:value-of select="character_bio/class"/>
		<xsl:if test="character_bio/class='Cleric' or character_bio/class='Paladin'">
			<xsl:if test="count(character_bio/deity) and character_bio/deity != ''">
				<xsl:text> of </xsl:text>
				<xsl:value-of select="character_bio/deity"/>
			</xsl:if>
		</xsl:if>
		<xsl:if test="count(character_bio/paragon_path) and character_bio/paragon_path != ''">
			<xsl:text> / </xsl:text>
			<xsl:value-of select="character_bio/paragon_path"/>
		</xsl:if>
		<xsl:if test="count(character_bio/epic_destiny) and character_bio/epic_destiny != ''">
			<xsl:text> / </xsl:text>
			<xsl:value-of select="character_bio/epic_destiny"/>
		</xsl:if>
		<xsl:text> </xsl:text>
		<xsl:value-of select="character_bio/level"/>
	</xsl:template>

</xsl:stylesheet>
