<?xml version="1.0" encoding="UTF-8"?>
<!--
	pcxml2pcint.xsl
	Created by Jay Elmore on 2008-05-12
	Copyright (c) 2008 Jay Elmore. All rights reserved.
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output encoding="UTF-8" indent="yes" method="xml"/>

	<!-- ####################################### -->
	<!-- Various precalculated bits we might use -->
	<!-- ####################################### -->
	<xsl:variable name="str-mod" select="floor((number(pcxml/stats/strength) - 10) div 2)"/>
	<xsl:variable name="con-mod" select="floor((number(pcxml/stats/constitution) - 10) div 2)"/>
	<xsl:variable name="dex-mod" select="floor((number(pcxml/stats/dexterity) - 10) div 2)"/>
	<xsl:variable name="int-mod" select="floor((number(pcxml/stats/intelligence) - 10) div 2)"/>
	<xsl:variable name="wis-mod" select="floor((number(pcxml/stats/wisdom) - 10) div 2)"/>
	<xsl:variable name="cha-mod" select="floor((number(pcxml/stats/charisma) - 10) div 2)"/>

	<xsl:variable name="level-mod" select="floor(number(pcxml/character_bio/level) div 2)"/>

	<xsl:variable name="bloodied-calc" select="floor(number(pcxml/combat/hit_points) div 2)"/>
	<xsl:variable name="surge-value-calc" select="floor(number(pcxml/combat/hit_points) div 4)"/>

	<xsl:variable name="passive-insight">
		<xsl:choose>
			<xsl:when test="count(pcxml/senses/passive_insight) and pcxml/senses/passive_insight != ''">
				<xsl:value-of select="pcxml/senses/passive_insight"/>
			</xsl:when>
			<xsl:when test="pcxml/senses/passive_insight = ''">
				<xsl:choose>
					<xsl:when test="pcxml/skills/skill[name='Insight']">
						<xsl:value-of select="floor(10 + $level-mod) + number(pcxml/skills/skill[name='Insight']/modifier)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="floor(10 + $wis-mod + $level-mod)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="count(pcxml/senses/passive_insight)=0">
				<xsl:choose>
					<xsl:when test="pcxml/skills/skill[name='Insight']">
						<xsl:value-of select="floor(10 + $level-mod) + number(pcxml/skills/skill[name='Insight']/modifier)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="floor(10 + $wis-mod + $level-mod)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="passive-perception">
		<xsl:choose>
			<xsl:when test="count(pcxml/senses/passive_perception) and pcxml/senses/passive_perception != ''">
				<xsl:value-of select="pcxml/senses/passive_perception"/>
			</xsl:when>
			<xsl:when test="pcxml/senses/passive_perception = ''">
				<xsl:choose>
					<xsl:when test="pcxml/skills/skill[name='Perception']">
						<xsl:value-of select="floor(10 + $level-mod) + number(pcxml/skills/skill[name='Perception']/modifier)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="floor(10 + $wis-mod + $level-mod)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="count(pcxml/senses/passive_perception)=0">
				<xsl:choose>
					<xsl:when test="pcxml/skills/skill[name='Perception']">
						<xsl:value-of select="floor(10 + $level-mod) + number(pcxml/skills/skill[name='Perception']/modifier)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="floor(10 + $wis-mod + $level-mod)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="basic-melee-mod" select="$str-mod + $level-mod"/>
	<xsl:variable name="basic-ranged-mod" select="$dex-mod + $level-mod"/>

	<!-- ########## -->
	<!-- This is a stylesheet to clean up and precalculate the intermediate source document, prior to final rendering. -->
	<!-- ########## -->

	<xsl:template match="/">
		<xsl:apply-templates select="pcxml"/>
	</xsl:template>

	<!-- ########## -->
	<!-- Main block -->
	<!-- ########## -->
	<xsl:template match="pcxml">
		<pcint>
			<xsl:apply-templates select="character_bio"/>
			<xsl:apply-templates select="stats"/>
			<xsl:apply-templates select="senses"/>
			<xsl:apply-templates select="combat"/>
			<xsl:apply-templates select="skills"/>
			<xsl:apply-templates select="feats"/>
			<xsl:apply-templates select="features"/>
			<xsl:apply-templates select="powers"/>
			<!--
				<xsl:apply-templates select="equipment"/>
				<xsl:apply-templates select="rituals"/>
			-->
			<!--			<xsl:call-template name="comments"/>-->
		</pcint>
	</xsl:template>

	<!-- ############# -->
	<!-- character_bio -->
	<!-- ############# -->
	<xsl:template match="character_bio">
		<character_bio>
			<name>
				<xsl:value-of select="name"/>
			</name>
			<xsl:if test="count(playername) and playername != ''">
				<playername>
					<xsl:value-of select="playername"/>
				</playername>
			</xsl:if>
			<xsl:if test="count(deity) and deity != ''">
				<deity>
					<xsl:value-of select="deity"/>
				</deity>
			</xsl:if>
			<alignment>
				<xsl:choose>
					<xsl:when test="count(alignment) and alignment != ''">
						<xsl:value-of select="alignment"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>Unaligned</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</alignment>
			<race>
				<xsl:value-of select="race"/>
			</race>
			<size>
				<xsl:choose>
					<xsl:when test="count(size) and size != ''">
						<xsl:value-of select="size"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>Medium</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</size>
			<class>
				<xsl:value-of select="class"/>
			</class>
			<level>
				<xsl:value-of select="level"/>
			</level>
			<level_mod>
				<xsl:value-of select="$level-mod"/>
			</level_mod>
			<xsl:if test="count(paragon_path) and paragon_path != ''">
				<paragon_path>
					<xsl:value-of select="paragon_path"/>
				</paragon_path>
			</xsl:if>
			<xsl:if test="count(epic_destiny) and epic_destiny != ''">
				<epic_destiny>
					<xsl:value-of select="epic_destiny"/>
				</epic_destiny>
			</xsl:if>
			<xsl:apply-templates select="language"/>
		</character_bio>
	</xsl:template>

	<xsl:template match="language">
		<language>
			<xsl:value-of select="text()"/>
		</language>
	</xsl:template>

	<!-- ##### -->
	<!-- stats -->
	<!-- ##### -->
	<xsl:template match="stats">
		<stats>
			<strength>
				<xsl:value-of select="strength"/>
			</strength>
			<str_mod>
				<xsl:value-of select="$str-mod"/>
			</str_mod>
			<constitution>
				<xsl:value-of select="constitution"/>
			</constitution>
			<con_mod>
				<xsl:value-of select="$con-mod"/>
			</con_mod>
			<dexterity>
				<xsl:value-of select="dexterity"/>
			</dexterity>
			<dex_mod>
				<xsl:value-of select="$dex-mod"/>
			</dex_mod>
			<intelligence>
				<xsl:value-of select="intelligence"/>
			</intelligence>
			<int_mod>
				<xsl:value-of select="$int-mod"/>
			</int_mod>
			<wisdom>
				<xsl:value-of select="wisdom"/>
			</wisdom>
			<wis_mod>
				<xsl:value-of select="$wis-mod"/>
			</wis_mod>
			<charisma>
				<xsl:value-of select="charisma"/>
			</charisma>
			<cha_mod>
				<xsl:value-of select="$cha-mod"/>
			</cha_mod>
		</stats>
	</xsl:template>

	<!-- ###### -->
	<!-- senses -->
	<!-- ###### -->
	<xsl:template match="senses">
		<senses>
			<vision>
				<xsl:choose>
					<xsl:when test="count(./vision) and ./vision != ''">
						<xsl:value-of select="./vision"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>Normal</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</vision>
			<passive_insight>
				<xsl:value-of select="$passive-insight"/>
			</passive_insight>
			<passive_perception>
				<xsl:value-of select="$passive-perception"/>
			</passive_perception>
		</senses>
	</xsl:template>

	<!-- ###### -->
	<!-- combat -->
	<!-- ###### -->
	<xsl:template match="combat">
		<combat>
			<hit_points>
				<xsl:value-of select="./hit_points"/>
			</hit_points>
			<bloodied>
				<xsl:choose>
					<xsl:when test="count(./bloodied) and ./bloodied != ''">
						<xsl:value-of select="./bloodied"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$bloodied-calc"/>
					</xsl:otherwise>
				</xsl:choose>
			</bloodied>
			<healing_surges>
				<xsl:value-of select="./healing_surges"/>
			</healing_surges>
			<surge_value>
				<xsl:choose>
					<xsl:when test="count(./surge_value) and ./surge_value != ''">
						<xsl:value-of select="./surge_value"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$surge-value-calc"/>
					</xsl:otherwise>
				</xsl:choose>
			</surge_value>
			<xsl:if test="count(./action_points) and ./action_points != ''">
				<action_points>
					<xsl:value-of select="./action_points"/>
				</action_points>
			</xsl:if>
			<initiative>
				<xsl:value-of select="./initiative"/>
			</initiative>
			<speed>
				<xsl:value-of select="./speed"/>
			</speed>
			<defenses>
				<armor_class>
					<xsl:value-of select="defenses/armor_class"/>
				</armor_class>
				<fortitude_defense>
					<xsl:value-of select="defenses/fortitude_defense"/>
				</fortitude_defense>
				<reflex_defense>
					<xsl:value-of select="defenses/reflex_defense"/>
				</reflex_defense>
				<will_defense>
					<xsl:value-of select="defenses/will_defense"/>
				</will_defense>
			</defenses>
			<xsl:apply-templates select="attacks"/>
		</combat>
	</xsl:template>
	<xsl:template match="attacks">
		<attacks>
			<xsl:apply-templates select="./melee"/>
			<xsl:apply-templates select="./ranged"/>
		</attacks>
	</xsl:template>
	<xsl:template match="melee">
		<xsl:if test="count(./name) and ./name != ''">
			<xsl:element name="melee">
				<xsl:attribute name="basic">
					<xsl:value-of select="./@basic"/>
				</xsl:attribute>
				<name>
					<xsl:value-of select="./name"/>
				</name>
				<attack_modifier>
					<xsl:value-of select="./attack_modifier"/>
				</attack_modifier>
				<vs_defense>
					<xsl:value-of select="./vs_defense"/>
				</vs_defense>
				<damage>
					<xsl:value-of select="./damage"/>
				</damage>
				<xsl:if test="count(./special_ability) and ./special_ability != ''">
					<special_ability>
						<xsl:value-of select="./special_ability"/>
					</special_ability>
				</xsl:if>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template match="ranged">
		<xsl:if test="count(./name) and ./name != ''">
			<xsl:element name="ranged">
				<xsl:attribute name="basic">
					<xsl:value-of select="./@basic"/>
				</xsl:attribute>
				<name>
					<xsl:value-of select="./name"/>
				</name>
				<attack_modifier>
					<xsl:value-of select="./attack_modifier"/>
				</attack_modifier>
				<vs_defense>
					<xsl:value-of select="./vs_defense"/>
				</vs_defense>
				<damage>
					<xsl:value-of select="./damage"/>
				</damage>
				<range_normal>
					<xsl:value-of select="./range_normal"/>
				</range_normal>
				<range_max>
					<xsl:value-of select="./range_max"/>
				</range_max>
				<xsl:if test="count(./special_ability) and ./special_ability != ''">
					<special_ability>
						<xsl:value-of select="./special_ability"/>
					</special_ability>
				</xsl:if>
			</xsl:element>
		</xsl:if>
	</xsl:template>

	<!-- ###### -->
	<!-- skills -->
	<!-- ###### -->
	<xsl:template match="skills">
		<skills>
			<xsl:apply-templates select="skill">
				<xsl:sort select="name"/>
			</xsl:apply-templates>
		</skills>
	</xsl:template>
	<xsl:template match="skill">
		<xsl:if test="count(./name) and ./name != ''">
			<skill>
				<name>
					<xsl:value-of select="./name"/>
				</name>
				<xsl:if test="count(./trained) and ./trained = 'Yes'">
					<trained>
						<xsl:value-of select="./trained"/>
					</trained>
				</xsl:if>
				<modifier>
					<xsl:value-of select="./modifier"/>
				</modifier>
			</skill>
		</xsl:if>
	</xsl:template>

	<!-- ##### -->
	<!-- feats -->
	<!-- ##### -->
	<xsl:template match="feats">
		<feats>
			<xsl:apply-templates select="feat">
				<xsl:sort select="name"/>
			</xsl:apply-templates>
		</feats>
	</xsl:template>
	<xsl:template match="feat">
		<xsl:if test="count(./name) and ./name != ''">
			<feat>
				<name>
					<xsl:value-of select="./name"/>
				</name>
				<description>
					<xsl:choose>
						<xsl:when test="count(./description) and ./description != ''">
							<xsl:value-of select="./description"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>see Powers</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</description>
			</feat>
		</xsl:if>
	</xsl:template> 

	<!-- ######## -->
	<!-- features -->
	<!-- ######## -->
	<xsl:template match="features">
		<features>
			<xsl:apply-templates select="feature">
				<xsl:sort select="name"/>
			</xsl:apply-templates>
		</features>
	</xsl:template>
	<xsl:template match="feature">
		<xsl:if test="count(./name) and ./name != ''">
			<xsl:element name="feature">
				<xsl:attribute name="type">
					<xsl:value-of select="./@type"/>
				</xsl:attribute>
				<name>
					<xsl:value-of select="./name"/>
				</name>
				<description>
					<xsl:choose>
						<xsl:when test="count(./description) and ./description != ''">
							<xsl:value-of select="./description"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>see Powers</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</description>
			</xsl:element>
		</xsl:if>
	</xsl:template> 

	<!-- ###### -->
	<!-- powers -->
	<!-- ###### -->
	<xsl:template match="powers">
		<powers>
			<xsl:apply-templates select="power">
				<xsl:sort select="./name"/>
			</xsl:apply-templates>
		</powers>
	</xsl:template>

	<xsl:template match="power">
		<xsl:if test="count(./name) and ./name != ''">
			<xsl:element name="power">
				<xsl:attribute name="category">
					<xsl:value-of select="./@category"/>
				</xsl:attribute>
				<name>
					<xsl:value-of select="./name"/>
				</name>
				<xsl:if test="count(./description)">
					<description>
						<xsl:value-of select="./description"/>
					</description>
				</xsl:if>
				<uses>
					<xsl:value-of select="./uses"/>
				</uses>
				<type>
					<xsl:value-of select="./type"/>
				</type>
				<xsl:apply-templates select="./keyword"/>
				<xsl:if test="count(./action_type) and ./action_type != ''">
					<action_type>
						<xsl:value-of select="./action_type"/>
					</action_type>
				</xsl:if>
				<xsl:if test="count(./prerequisite) and ./prerequisite != ''">
					<prerequisite>
						<xsl:value-of select="./prerequisite"/>
					</prerequisite>
				</xsl:if>
				<xsl:if test="count(./requirement) and ./requirement != ''">
					<requirement>
						<xsl:value-of select="./requirement"/>
					</requirement>
				</xsl:if>
				<xsl:if test="count(./range) and ./range != ''">
					<range>
						<xsl:value-of select="./range"/>
					</range>
				</xsl:if>
				<xsl:if test="count(./area) and ./area != ''">
					<area>
						<xsl:value-of select="./area"/>
					</area>
				</xsl:if>
				<xsl:if test="count(./special) and ./special != ''">
					<special>
						<xsl:value-of select="./special"/>
					</special>
				</xsl:if>
				<xsl:apply-templates select="./primary"/>
				<xsl:apply-templates select="./secondary"/>
				<xsl:apply-templates select="./tertiary"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>

	<xsl:template match="keyword">
		<keyword>
			<xsl:value-of select="text()"/>
		</keyword>
	</xsl:template>

	<xsl:template match="primary | secondary | tertiary">
		<xsl:choose>
			<xsl:when test="name()='secondary'">
				<xsl:element name="secondary">
					<xsl:if test="count(./target) and ./target != ''">
						<target>
							<xsl:value-of select="./target"/>
						</target>
					</xsl:if>
					<xsl:if test="count(./attack_modifier) and ./attack_modifier != ''">
						<attack_modifier>
							<xsl:value-of select="./attack_modifier"/>
						</attack_modifier>
					</xsl:if>
					<xsl:if test="count(./vs_defense) and ./vs_defense != ''">
						<vs_defense>
							<xsl:value-of select="./vs_defense"/>
						</vs_defense>
					</xsl:if>
					<xsl:if test="count(./hit) and ./hit != ''">
						<hit>
							<xsl:value-of select="./hit"/>
						</hit>
					</xsl:if>
					<xsl:if test="count(./miss) and ./miss != ''">
						<miss>
							<xsl:value-of select="./miss"/>
						</miss>
					</xsl:if>
					<xsl:if test="count(./effect) and ./effect != ''">
						<effect>
							<xsl:value-of select="./effect"/>
						</effect>
					</xsl:if>
					<xsl:if test="count(./sustain) and ./sustain != ''">
						<sustain>
							<xsl:value-of select="./sustain"/>
						</sustain>
					</xsl:if>
				</xsl:element>
			</xsl:when>
			<xsl:when test="name()='tertiary'">
				<xsl:element name="tertiary">
					<xsl:if test="count(./target) and ./target != ''">
						<target>
							<xsl:value-of select="./target"/>
						</target>
					</xsl:if>
					<xsl:if test="count(./attack_modifier) and ./attack_modifier != ''">
						<attack_modifier>
							<xsl:value-of select="./attack_modifier"/>
						</attack_modifier>
					</xsl:if>
					<xsl:if test="count(./vs_defense) and ./vs_defense != ''">
						<vs_defense>
							<xsl:value-of select="./vs_defense"/>
						</vs_defense>
					</xsl:if>
					<xsl:if test="count(./hit) and ./hit != ''">
						<hit>
							<xsl:value-of select="./hit"/>
						</hit>
					</xsl:if>
					<xsl:if test="count(./miss) and ./miss != ''">
						<miss>
							<xsl:value-of select="./miss"/>
						</miss>
					</xsl:if>
					<xsl:if test="count(./effect) and ./effect != ''">
						<effect>
							<xsl:value-of select="./effect"/>
						</effect>
					</xsl:if>
					<xsl:if test="count(./sustain) and ./sustain != ''">
						<sustain>
							<xsl:value-of select="./sustain"/>
						</sustain>
					</xsl:if>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="primary">
					<xsl:if test="count(./target) and ./target != ''">
						<target>
							<xsl:value-of select="./target"/>
						</target>
					</xsl:if>
					<xsl:if test="count(./attack_modifier) and ./attack_modifier != ''">
						<attack_modifier>
							<xsl:value-of select="./attack_modifier"/>
						</attack_modifier>
					</xsl:if>
					<xsl:if test="count(./vs_defense) and ./vs_defense != ''">
						<vs_defense>
							<xsl:value-of select="./vs_defense"/>
						</vs_defense>
					</xsl:if>
					<xsl:if test="count(./hit) and ./hit != ''">
						<hit>
							<xsl:value-of select="./hit"/>
						</hit>
					</xsl:if>
					<xsl:if test="count(./miss) and ./miss != ''">
						<miss>
							<xsl:value-of select="./miss"/>
						</miss>
					</xsl:if>
					<xsl:if test="count(./effect) and ./effect != ''">
						<effect>
							<xsl:value-of select="./effect"/>
						</effect>
					</xsl:if>
					<xsl:if test="count(./sustain) and ./sustain != ''">
						<sustain>
							<xsl:value-of select="./sustain"/>
						</sustain>
					</xsl:if>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<xsl:template name="comments">
		<xsl:text>&#xA;</xsl:text>
		<xsl:comment>
			<xsl:text>Level mod: </xsl:text>
			<xsl:value-of select="$level-mod"/>
			<xsl:text> Calculated bloodied: </xsl:text>
			<xsl:value-of select="$bloodied-calc"/>
			<xsl:text> Calculated surge HP: </xsl:text>
			<xsl:value-of select="$surge-value-calc"/>
			<xsl:text> Calculated Passive Insight: </xsl:text>
			<xsl:value-of select="$passive-insight"/>
			<xsl:text> Calculated Passive Perception: </xsl:text>
			<xsl:value-of select="$passive-perception"/>
			<xsl:text> Str mod: </xsl:text>
			<xsl:value-of select="$str-mod"/>
			<xsl:text> Con mod: </xsl:text>
			<xsl:value-of select="$con-mod"/>
			<xsl:text> Dex mod: </xsl:text>
			<xsl:value-of select="$dex-mod"/>
			<xsl:text> Int mod: </xsl:text>
			<xsl:value-of select="$int-mod"/>
			<xsl:text> Wis mod: </xsl:text>
			<xsl:value-of select="$wis-mod"/>
			<xsl:text> Cha mod: </xsl:text>
			<xsl:value-of select="$cha-mod"/>
		</xsl:comment>
	</xsl:template>
</xsl:stylesheet>
